from django.shortcuts import render
from django.http import JsonResponse
import jieba
import jieba.posseg as posseg
# Create your views here.

def cut(request):
	if request.POST and request.method == 'POST':
		data = request.POST
		data = data.dict()
		return JsonResponse(jieba.lcut(data['sentence']), safe=False)
	return JsonResponse({'result':False}, safe=False)

def pos(request):
	if request.POST and request.method == 'POST':
		data = request.POST
		data = data.dict()
		return JsonResponse( list(map(lambda x:tuple(x), posseg.lcut(data['sentence']))), safe=False)
	return JsonResponse({'result':False}, safe=False)


from distutils.core import setup

setup(
    name = 'jiebaWebApi',
    packages = ['jiebaWebApi'],
    version = '1.1',
    description = 'A Web Api for Jieba.',
    author = 'davidtnfsh',
    author_email = 'davidtnfsh@gmail.com',
    url = 'https://github.com/udicatnchu/jiebaWebApi',
    download_url = 'https://github.com/udicatnchu/jiebaWebApi/archive/v1.1.tar.gz',
    keywords = ['jieba', 'word segmentation'],
    classifiers = [],
    license='MIT',
    install_requires=[
        'jieba==0.38',
    ],
    zip_safe=True
)
